@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2004 by Raul Fernandes                                  *
+ *   Copyright (C) 2004-2006 by Raul Fernandes                             *
  *   rgfbr@yahoo.com.br                                                    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -25,10 +25,12 @@
 #include "ktranslatordock.h"
 #include "resultswindow.h"
 #include "generalsettings.h"
+#include "advancedsettings.h"
 #include "colorssettings.h"
 #include "dictionariessettings.h"
 #include "config.h"
 #include "ktranslatordictionary.h"
+#include "ktranslatordictionarymanager.h"
 
 #include <dictionary/dictionaryplugin.h>
 #include <ui/uiplugin.h>
@@ -47,7 +49,6 @@
 #include <qfile.h>
 #include <qtextstream.h>
 #include <qtimer.h>
-#include <qlistbox.h>
 #include <qdatetime.h>
 #include <qregexp.h>
 
@@ -95,6 +96,7 @@ ktranslator::ktranslator()
     lineedit = new QLineEdit( hbox );
     QWhatsThis::add( lineedit, i18n( "Enter the word to be searched here and click in \"Translate\" to translate the word" ) );
     connect( lineedit, SIGNAL( returnPressed() ), this, SLOT( searchLineedit() ) );
+    connect( lineedit, SIGNAL( returnPressed() ), lineedit, SLOT( selectAll() ) );
 
     QPushButton *button = new QPushButton ( i18n( "Translate" ), hbox );
     button->resize( 30, 20 );
@@ -102,7 +104,7 @@ ktranslator::ktranslator()
     connect( button, SIGNAL( clicked() ), this, SLOT( searchLineedit() ) );
 
     main = new QTextBrowser( vbox );
-    main->setText( i18n( "To translate a word, select the word. The easiest way to select the word is double clicking in it.\nIt will appears a passive popup with the translation of word." ) );
+    main->setText( i18n( "To translate a word, select the word. The easiest way to select the word is double clicking in it.\nA passive popup with the translation of the word will appear." ) );
     connect( main, SIGNAL( linkClicked( const QString & ) ), this, SLOT( linkClicked( const QString & ) ) );
 
     vbox->adjustSize();
@@ -118,6 +120,10 @@ ktranslator::ktranslator()
     dock->actionCollection()->insert( actionConfig );
     actionConfig->plug( dock->contextMenu() );
 
+    KAction *actionQuit = new KAction( i18n( "Quit" ), "exit", 0, this, SLOT( slotQuit() ), actionCollection(), "quit" );
+    actionQuit->setWhatsThis( i18n( "Click here to exit from application" ) );
+    menuQuit = false;
+
     setCentralWidget( vbox );
     createGUI();
 
@@ -172,15 +178,24 @@ QString ktranslator::translate( const QString &text )
     QTime time;
   #endif
 
-  word.remove( "." ); // remove dots from the word
+  word.remove( "." ).remove( "," ).remove( ";" ); // remove dots and commas from the word
   word = word.lower().stripWhiteSpace();
   result += "<tr><td><b>" + i18n( "Word to translate:" ) + "<br><font color=" + config::headwordColor().name() + ">" + word + "</font><br></b></td></tr>";
 
+  #ifndef NDEBUG
+    time.start();
+  #endif
+
   // search the word in index file
   QString indexResult = searchIndex( word );
+
+  #ifndef NDEBUG
+    kdDebug() << "Index: search in " << time.elapsed() << "ms" << endl;
+  #endif
+
   // test if searchIndex returns something
   // if yes, show it
-  if( !indexResult.isEmpty() ) result += "<tr><td>" + indexResult + "</td></tr>";
+  if( !indexResult.isEmpty() && config::showDetails() ) result += "<tr><td>" + indexResult + "</td></tr>";
 
   QString dicResult;
   // search in dictionaries
@@ -196,7 +211,7 @@ QString ktranslator::translate( const QString &text )
     if( config::showEmptyResult() || dicResult.find( i18n( "Word not found" ) ) == -1 ) result += "<tr><td>" + dicResult + "</td></tr>";
 
     #ifndef NDEBUG
-      kdDebug() << "Procurar: " << dic->name() << " - search in " << time.elapsed() << "ms" << endl;
+      kdDebug() << "Search: " << dic->name() << " - search in " << time.elapsed() << "ms" << endl;
     #endif
 
   }
@@ -206,6 +221,8 @@ QString ktranslator::translate( const QString &text )
   {
     result += "</table></body></html>";
 
+    if( !config::showDetails() ) result.replace( QRegExp( "<pos>[^<]*</pos>" ), "" );
+
     // dictionary name
     result.replace( "<dicName>", "<font color=" + config::nameColor().name() + "><b>" );
     result.replace( "</dicName>", "</b></font><br>" );
@@ -233,7 +250,7 @@ QString ktranslator::translate( const QString &text )
 // unless the session is being saved for a logout
 bool ktranslator::queryClose()
 {
-  if( !kapp->sessionSaving() )
+  if( !menuQuit && !kapp->sessionSaving() )
   {
     hide();
     return false;
@@ -241,6 +258,14 @@ bool ktranslator::queryClose()
   return true;
 }
 
+
+void ktranslator::slotQuit()
+{
+  menuQuit = true;
+  kapp->quit();
+}
+
+
 void ktranslator::speech()
 {
    QString word = wordToTranslate;
@@ -260,10 +285,18 @@ void ktranslator::searchInInternet()
 {
    QString word = wordToTranslate;
    QStringList addresses;
-   addresses.append( "http://www.m-w.com/cgi-bin/dictionary?book=Dictionary&va=" + word );
-   addresses.append( "http://www.dict.org/bin/Dict?Form=Dict2&Database=*&Query=" + word );
-   addresses.append( "http://en.wikipedia.org/wiki/" + word );
-   addresses.append( "http://en.wiktionary.org/wiki/" + word );
+   QStringList sites = config::sitesToSearch();
+   QString site;
+   for( QStringList::Iterator it = sites.begin(); it != sites.end(); ++it )
+   {
+     site = *it;
+     addresses.append( site.replace( "\\{@}", word ) );
+   }
+   #ifndef NDEBUG
+
+     kdDebug() << "StringList " << addresses << endl;
+
+   #endif
    /*kapp->startServiceByName( "Web Browser", addresses, NULL, NULL, NULL, NULL, true );*/
    KApplication::kdeinitExec( "konqueror", addresses );
 }
@@ -283,19 +316,13 @@ void ktranslator::slotConfig()
    ColorsSettings *colors = new ColorsSettings( 0, "Colors" );
    dialog->addPage( colors, i18n( "Colors" ), "configure" );
 
+   // Colors settings page
+   AdvancedSettings *advanced = new AdvancedSettings( 0, "Advanced" );
+   dialog->addPage( advanced, i18n( "Advanced" ), "configure" );
+
    // Dictionaries page
-   DictionariesSettings *dictionaries = new DictionariesSettings( 0, "Dictionaries" );
+   DictionariesSettings *dictionaries = new DictionariesSettings( plugins, 0, "Dictionaries" );
    dialog->addPage( dictionaries, i18n( "Dictionaries" ), "configure" );
-   dictionaries->editButton->hide();
-   //dictionaries->dicList->addColumn( "Dictionaries" );
-   for( KTranslatorDictionary *dic = plugins->list.first(); dic; dic = plugins->list.next() )
-   {
-     dictionaries->dicList->insertItem( dic->name() );
-   }
-   connect( dictionaries->addButton, SIGNAL( clicked() ), this, SLOT( addDictionary() ) );
-   dictionaries->editButton->setEnabled( false );
-   //connect( dictionaries->editButton, SIGNAL( clicked() ), this, SLOT( editDictionary() ) );
-   connect( dictionaries->removeButton, SIGNAL( clicked() ), this, SLOT( removeDictionary() ) );
 
    connect( dialog, SIGNAL( settingsChanged() ), this, SLOT( updateConfig() ) );
    connect( dialog, SIGNAL( okClicked() ), this, SLOT( updateConfig() ) );
@@ -304,63 +331,6 @@ void ktranslator::slotConfig()
 }
 
 
-void ktranslator::addDictionary()
-{
-  // Add the dictionary
-  plugins->addDictionary();
-
-  // Refresh list of dictionaries in config dialog
-  KConfigDialog *dialog = KConfigDialog::exists( "settings" );
-  if( dialog == NULL ) return;
-
-  QListBox *dicList = (QListBox *)(dialog->child( "Dictionaries" )->child( "dicList" ));
-  dicList->clear();
-  for( KTranslatorDictionary *dic = plugins->list.first(); dic; dic = plugins->list.next() )
-  {
-    dicList->insertItem( dic->name() );
-  }
-}
-
-
-void ktranslator::editDictionary()
-{
-  KConfigDialog *dialog = KConfigDialog::exists( "settings" );
-  if( dialog == NULL ) return;
-
-  QListBox *dicList = (QListBox *)(dialog->child( "Dictionaries" )->child( "dicList" ));
-  int item = dicList->currentItem();
-
-  plugins->editDictionary( item );
-
-  // Refresh the dictionary list
-  dicList->clear();
-  for( KTranslatorDictionary *dic = plugins->list.first(); dic; dic = plugins->list.next() )
-  {
-    dicList->insertItem( dic->name() );
-  }
-}
-
-
-void ktranslator::removeDictionary()
-{
-  KConfigDialog *dialog = KConfigDialog::exists( "settings" );
-  if( dialog == NULL ) return;
-
-  QListBox *dicList = (QListBox *)(dialog->child( "Dictionaries" )->child( "dicList" ));
-  int item = dicList->currentItem();
-
-  // Remove the dictionary
-  plugins->removeDictionary( item );
-
-  // Refresh the dictionary list
-  dicList->clear();
-  for( KTranslatorDictionary *dic = plugins->list.first(); dic; dic = plugins->list.next() )
-  {
-    dicList->insertItem( dic->name() );
-  }
-}
-
-
 void ktranslator::updateConfig()
 {
   // Call the function in UI plugins to change the
