@@ -1,7 +1,7 @@
 /***************************************************************************
- *  libbab.cc -- BabyTrans ( Babylon Translator front-end for GTK )
- *
- *  Copyright (C) 1999-2002  Frederic Jolliton -- <babytrans@tuxee.net>
+ *  libbab.cc -- BabyTrans ( Babylon Translator front-end for GTK )        *
+ *                                                                         *
+ *  Copyright (C) 1999-2002  Frederic Jolliton -- <babytrans@tuxee.net>    *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -556,8 +556,7 @@ Babylon::translatePriv( const std::string& word ,
 				mainPosition = 100 + 4 * ( ( def >> 16 ) & 0xFFFF ) ;
 				myFileDef.seekg( mainPosition ) ;
 				positionDef = readU32( myFileDef ) ;
-				wordPosition = def & 0xffff ;
-				myFileDef.seekg( positionDef + 4 * wordPosition ) ;
+				myFileDef.seekg( positionDef + 4 * (def & 0xffff) ) ;
 				def = readU32( myFileDef ) ;
 			}
 			/* Now, we have the position into the definition file
